==> seqan2_2.4.0+dfsg.orig.tar.xz: seqan-seqan-v2.4.0/tests/modifier/helpers.h <==
// ==========================================================================
//                 SeqAn - The Library for Sequence Analysis
// ==========================================================================
// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of Knut Reinert or the FU Berlin nor the names of
//       its contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL KNUT REINERT OR THE FU BERLIN BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
// DAMAGE.
//
// ==========================================================================
// Helpers for the test_modifier tests.
// ==========================================================================

#ifndef TESTS_MODIFIER_HELPERS_H_
#define TESTS_MODIFIER_HELPERS_H_

#include <functional>

// Cesar Chiffre as a test functor.
template <typename TArgChar, typename TResultChar = TArgChar>
struct CaesarChiffre : public std::unary_function<TArgChar, TResultChar>
{
    TArgChar _delta;

    CaesarChiffre() : _delta(0) {}
    CaesarChiffre(CaesarChiffre &other) : _delta(other._delta) {}
    CaesarChiffre(CaesarChiffre const &other) : _delta(other._delta) {}

    CaesarChiffre(TArgChar delta) {
        if (delta < 0)
            _delta = ('z' - 'a' + 1) - (-delta) % ('z' - 'a' + 1);
        else
            _delta = delta;
    }

    inline TResultChar operator()(TArgChar const & x) const {
        if (('a' <= x) && (x <= 'z'))
            return (x - 'a' + _delta) % ('z' - 'a' + 1) + 'a';
        if (('A' <= x) && (x <= 'Z'))
            return (x - 'A' + _delta) % ('Z' - 'A' + 1) + 'A';
        return x;
    }
};


#endif  // TESTS_MODIFIER_HELPERS_H_

==> seqan2_2.5.0~rc3+dfsg.orig.tar.xz: seqan-seqan-v2.5.0rc3/tests/modifier/helpers.h <==
// ==========================================================================
//                 SeqAn - The Library for Sequence Analysis
// ==========================================================================
// Copyright (c) 2006-2024, Knut Reinert, FU Berlin
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of Knut Reinert or the FU Berlin nor the names of
//       its contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL KNUT REINERT OR THE FU BERLIN BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
// DAMAGE.
//
// ==========================================================================
// Helpers for the test_modifier tests.
// ==========================================================================

#ifndef TESTS_MODIFIER_HELPERS_H_
#define TESTS_MODIFIER_HELPERS_H_

#include <functional>

// Cesar Chiffre as a test functor.
template <typename TArgChar, typename TResultChar = TArgChar>
struct CaesarChiffre : public std::function<TResultChar(TArgChar)>
{
    TArgChar _delta;

    CaesarChiffre() : _delta(0) {}
    CaesarChiffre(CaesarChiffre const &other) = default;
    CaesarChiffre & operator=(CaesarChiffre const &) = default;

    CaesarChiffre(TArgChar delta) {
        if (delta < 0)
            _delta = ('z' - 'a' + 1) - (-delta) % ('z' - 'a' + 1);
        else
            _delta = delta;
    }

    inline TResultChar operator()(TArgChar const & x) const {
        if (('a' <= x) && (x <= 'z'))
            return (x - 'a' + _delta) % ('z' - 'a' + 1) + 'a';
        if (('A' <= x) && (x <= 'Z'))
            return (x - 'A' + _delta) % ('Z' - 'A' + 1) + 'A';
        return x;
    }
};


#endif  // TESTS_MODIFIER_HELPERS_H_
